@@ -34,7 +34,7 @@ package App::Dochazka::Common::Model;
 
 use 5.012;
 use strict;
-use warnings FATAL => 'all';
+use warnings;
 
 use Params::Validate qw( :all );
 use Test::Deep::NoTest;
@@ -276,6 +276,7 @@ sub make_accessor {
         my $self = shift;
         validate_pos( @_, { type => $type, optional => 1 } );
         $self->{$subname} = shift if @_;
+        $self->{$subname} = undef unless exists $self->{$subname};
         return $self->{$subname};
     };
 }
